<?php
/*
Plugin Name: Category Related Links
Version: 1.0 Beta 1
Plugin URI: http://jp.jixor.com/archives/related-links/
Author: Stephen Ingram
Author URI: http://www.jixor.com/
Description: Manage links attaching them to the same category structure as used for your blog articles. You may then display related links based on the current articles category. You may use the <a href="jp-linksedit.php"><strong>Manage Links Page</strong></a> to manage links and install the database tables (Only if you have correctly installed the admin component.).
*/

/* ************************************************************************

JP_BCT License (based on BSD license)
Copyright (c) 2005, jp.jixor.com, Stephen Ingram
All rights reserved.

	PREAMBLE

  Feel free to modify the source providing you stick the the following
conditions. Please also inform me of any modifications you make so that I
may possibly add them to the release on my site. I will credit authors
where appropriate. License may change. However this is fairly simple,
basically don't claim its your own and I'm not responsible for your use of
it.

---------------------------------------------------------------------------

	LICENSE

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1) Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.

2) Neither the name of jixor.com, nor the names of its
   contributors may be used to endorse or promote products derived from this
   software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
POSSIBILITY OF SUCH DAMAGE.

************************************************************************ */

/*
Some SQL fun for you, if you want to do a manual install.

CREATE TABLE `wp_jp_links` (
`jplink_id` INT( 11 ) NOT NULL AUTO_INCREMENT ,
`jplink_name` VARCHAR( 255 ) NOT NULL ,
`jplink_url` VARCHAR( 255 ) NOT NULL ,
`jplink_description` VARCHAR( 255 ) NOT NULL ,
`jplink_date` DATETIME NOT NULL ,
`jplink_visible` ENUM( 'Y', 'N' ) DEFAULT 'Y' NOT NULL ,
PRIMARY KEY ( `jplink_id` )
);

CREATE TABLE `wp_jp_link2cat` (
`rel_id` INT( 11 ) NOT NULL AUTO_INCREMENT ,
`category_id` INT( 11 ) NOT NULL ,
`jplink_id` INT( 11 ) NOT NULL ,
PRIMARY KEY ( `rel_id` )
);

*/

/*
Multilingual feature will be added at a later date. Currently to translate you must edit various lines in the source.
*/

// You may use also one of the following names.
$jp_catrellinks = 'jp_links';
$jp_crl = 'jp_links';

function jp_links($displayeachonce=TRUE,$showstats=TRUE,$before='<ul>Related Links',$after='</ul>',$eachbefore='<li>%catname%<ul>',$eachafter='</ul><span class="meta">%stats%</span></li>',$eachlink='<li><a href="%url%" title="%description%">%name%</a></li>',$dateformat='r') {

	// Initialize
	global $table_prefix, $single, $wpdb;

	// Place settings in an external ini file, awsome. May become editable through admin component in the future.
	if (file_exists('wp-content/jp-links/jp-links.ini')) extract(parse_ini_file('wp-content/jp-links/jp-links.ini'));

	// Begin ff single wrapper - Only run this script if the user is viewing an individual post, as used on comments.
	if($single) {
	//

	$tablejplinks		= $table_prefix . 'jp_links';
	$tablejplink2cat	= $table_prefix . 'jp_link2cat';

	$categories = get_the_category();

	$links = array();

	foreach($categories as $category) {

		$response = $wpdb->get_results("
SELECT $tablejplinks.*
FROM  $tablejplinks, $tablejplink2cat
WHERE $tablejplink2cat.category_id = $category->category_id AND $tablejplink2cat.jplink_id = $tablejplinks.jplink_id AND $tablejplinks.jplink_visible = 'Y'
");

		if ($response) {
			$links[$category->cat_name] = $response;
		}

	}

	$usedlinks = array(); // Srore link ids that have been used so there are no repeats (optional).

	$linkelements = array('id','name','url','description','date','visible'); // For templating - text replacment.


	if (!empty($links)) echo $before;

	foreach($links as $catname => $linkset) { // If no links then its just an empty array so that won't be a problem.

		echo str_replace('%catname%',$catname,$eachbefore);

		$alreadyused = 0;

		foreach ($linkset as $link) {

			$echo = $eachlink;

			$link->jplink_date = date($dateformat,strtotime($link->jplink_date));

			if ((!in_array($link->jplink_id,$usedlinks)) and ($displayeachonce)) {

				foreach($linkelements as $linkelement) {
					$element = 'jplink_'.$linkelement;
					$echo = str_replace('%'.$linkelement.'%',$link->$element,$echo);
				}

				echo $echo;

				$usedlinks[] = $link->jplink_id;

			} elseif (!$displayeachonce) {

				foreach($linkelements as $linkelement) {
					$element = 'jplink_'.$linkelement;
					$echo = str_replace('%'.$linkelement.'%',$link->$element,$echo);
				}

				echo $echo;

				// I can also see the above code twice ;)

			} else {

				$alreadyused++;

			}

		}

		if($showstats) {

			$count = count($linkset);
			$stats = '<span class="jplinksstats">'.$count;
			if ($count == 1) {
				$stats .= ' link found in '.$catname;
			} else {
				$stats .= ' links found in '.$catname;
			}

			// If using displayonce and links have already been displayed for this category.
			if (($displayeachonce) and ($alreadyused)) {
				$stats .= ' with '.$alreadyused;
				if ($alreadyused == 1) {
					$stats .= ' link hidden as it has already been displayed in another category';
				} else {
					$stats .= ' links hidden as they have already been displayed in other categories';
				}
			}

			$stats .= '</span>';

		}

		echo str_replace('%stats%',$stats,$eachafter);

	}

	if (!empty($links)) echo $after;

	//
	} else {
	// End If single wrapper
	//echo '<p>JP_LINKS: not single</p>'; // For debug if you want.
	// I could make a relevant links counter display, but that would be kind of pointless.
	// However if you want one just ask - in the comments.
	}

}

?>
